/****************************************************************************
** Meta object code from reading C++ file 'mediaplayer2player.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/mpris2/mediaplayer2player.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplayer2player.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_MediaPlayer2Player_t {
    QByteArrayData data[42];
    char stringdata0[442];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MediaPlayer2Player_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MediaPlayer2Player_t qt_meta_stringdata_MediaPlayer2Player = {
    {
QT_MOC_LITERAL(0, 0, 18), // "MediaPlayer2Player"
QT_MOC_LITERAL(1, 19, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 35, 29), // "org.mpris.MediaPlayer2.Player"
QT_MOC_LITERAL(3, 65, 6), // "Seeked"
QT_MOC_LITERAL(4, 72, 0), // ""
QT_MOC_LITERAL(5, 73, 8), // "Position"
QT_MOC_LITERAL(6, 82, 4), // "Next"
QT_MOC_LITERAL(7, 87, 8), // "Previous"
QT_MOC_LITERAL(8, 96, 5), // "Pause"
QT_MOC_LITERAL(9, 102, 9), // "PlayPause"
QT_MOC_LITERAL(10, 112, 4), // "Stop"
QT_MOC_LITERAL(11, 117, 4), // "Play"
QT_MOC_LITERAL(12, 122, 4), // "Seek"
QT_MOC_LITERAL(13, 127, 6), // "Offset"
QT_MOC_LITERAL(14, 134, 11), // "SetPosition"
QT_MOC_LITERAL(15, 146, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(16, 162, 7), // "TrackId"
QT_MOC_LITERAL(17, 170, 7), // "OpenUri"
QT_MOC_LITERAL(18, 178, 3), // "Uri"
QT_MOC_LITERAL(19, 182, 4), // "tick"
QT_MOC_LITERAL(20, 187, 6), // "newPos"
QT_MOC_LITERAL(21, 194, 18), // "emitMetadataChange"
QT_MOC_LITERAL(22, 213, 20), // "currentSourceChanged"
QT_MOC_LITERAL(23, 234, 12), // "stateUpdated"
QT_MOC_LITERAL(24, 247, 16), // "totalTimeChanged"
QT_MOC_LITERAL(25, 264, 15), // "seekableChanged"
QT_MOC_LITERAL(26, 280, 8), // "seekable"
QT_MOC_LITERAL(27, 289, 13), // "volumeChanged"
QT_MOC_LITERAL(28, 303, 14), // "PlaybackStatus"
QT_MOC_LITERAL(29, 318, 10), // "LoopStatus"
QT_MOC_LITERAL(30, 329, 4), // "Rate"
QT_MOC_LITERAL(31, 334, 7), // "Shuffle"
QT_MOC_LITERAL(32, 342, 8), // "Metadata"
QT_MOC_LITERAL(33, 351, 6), // "Volume"
QT_MOC_LITERAL(34, 358, 11), // "MinimumRate"
QT_MOC_LITERAL(35, 370, 11), // "MaximumRate"
QT_MOC_LITERAL(36, 382, 9), // "CanGoNext"
QT_MOC_LITERAL(37, 392, 13), // "CanGoPrevious"
QT_MOC_LITERAL(38, 406, 7), // "CanPlay"
QT_MOC_LITERAL(39, 414, 8), // "CanPause"
QT_MOC_LITERAL(40, 423, 7), // "CanSeek"
QT_MOC_LITERAL(41, 431, 10) // "CanControl"

    },
    "MediaPlayer2Player\0D-Bus Interface\0"
    "org.mpris.MediaPlayer2.Player\0Seeked\0"
    "\0Position\0Next\0Previous\0Pause\0PlayPause\0"
    "Stop\0Play\0Seek\0Offset\0SetPosition\0"
    "QDBusObjectPath\0TrackId\0OpenUri\0Uri\0"
    "tick\0newPos\0emitMetadataChange\0"
    "currentSourceChanged\0stateUpdated\0"
    "totalTimeChanged\0seekableChanged\0"
    "seekable\0volumeChanged\0PlaybackStatus\0"
    "LoopStatus\0Rate\0Shuffle\0Metadata\0"
    "Volume\0MinimumRate\0MaximumRate\0CanGoNext\0"
    "CanGoPrevious\0CanPlay\0CanPause\0CanSeek\0"
    "CanControl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MediaPlayer2Player[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      17,   16, // methods
      15,  132, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,  101,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  104,    4, 0x0a /* Public */,
       7,    0,  105,    4, 0x0a /* Public */,
       8,    0,  106,    4, 0x0a /* Public */,
       9,    0,  107,    4, 0x0a /* Public */,
      10,    0,  108,    4, 0x0a /* Public */,
      11,    0,  109,    4, 0x0a /* Public */,
      12,    1,  110,    4, 0x0a /* Public */,
      14,    2,  113,    4, 0x0a /* Public */,
      17,    1,  118,    4, 0x0a /* Public */,
      19,    1,  121,    4, 0x08 /* Private */,
      21,    0,  124,    4, 0x08 /* Private */,
      22,    0,  125,    4, 0x08 /* Private */,
      23,    0,  126,    4, 0x08 /* Private */,
      24,    0,  127,    4, 0x08 /* Private */,
      25,    1,  128,    4, 0x08 /* Private */,
      27,    0,  131,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::LongLong,    5,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   13,
    QMetaType::Void, 0x80000000 | 15, QMetaType::LongLong,   16,    5,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void, QMetaType::LongLong,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void,

 // properties: name, type, flags
      28, QMetaType::QString, 0x00095001,
      29, QMetaType::QString, 0x00095103,
      30, QMetaType::Double, 0x00095103,
      31, QMetaType::Bool, 0x00095103,
      32, QMetaType::QVariantMap, 0x00095001,
      33, QMetaType::Double, 0x00095103,
       5, QMetaType::LongLong, 0x00095001,
      34, QMetaType::Double, 0x00095001,
      35, QMetaType::Double, 0x00095001,
      36, QMetaType::Bool, 0x00095001,
      37, QMetaType::Bool, 0x00095001,
      38, QMetaType::Bool, 0x00095001,
      39, QMetaType::Bool, 0x00095001,
      40, QMetaType::Bool, 0x00095001,
      41, QMetaType::Bool, 0x00095001,

       0        // eod
};

void MediaPlayer2Player::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MediaPlayer2Player *_t = static_cast<MediaPlayer2Player *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->Seeked((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 1: _t->Next(); break;
        case 2: _t->Previous(); break;
        case 3: _t->Pause(); break;
        case 4: _t->PlayPause(); break;
        case 5: _t->Stop(); break;
        case 6: _t->Play(); break;
        case 7: _t->Seek((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 8: _t->SetPosition((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2]))); break;
        case 9: _t->OpenUri((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 10: _t->tick((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 11: _t->emitMetadataChange(); break;
        case 12: _t->currentSourceChanged(); break;
        case 13: _t->stateUpdated(); break;
        case 14: _t->totalTimeChanged(); break;
        case 15: _t->seekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->volumeChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MediaPlayer2Player::*_t)(qlonglong ) const;
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MediaPlayer2Player::Seeked)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        MediaPlayer2Player *_t = static_cast<MediaPlayer2Player *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->PlaybackStatus(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->LoopStatus(); break;
        case 2: *reinterpret_cast< double*>(_v) = _t->Rate(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->Shuffle(); break;
        case 4: *reinterpret_cast< QVariantMap*>(_v) = _t->Metadata(); break;
        case 5: *reinterpret_cast< double*>(_v) = _t->Volume(); break;
        case 6: *reinterpret_cast< qlonglong*>(_v) = _t->Position(); break;
        case 7: *reinterpret_cast< double*>(_v) = _t->MinimumRate(); break;
        case 8: *reinterpret_cast< double*>(_v) = _t->MaximumRate(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->CanGoNext(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->CanGoPrevious(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->CanPlay(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->CanPause(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->CanSeek(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->CanControl(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        MediaPlayer2Player *_t = static_cast<MediaPlayer2Player *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setLoopStatus(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setRate(*reinterpret_cast< double*>(_v)); break;
        case 3: _t->setShuffle(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setVolume(*reinterpret_cast< double*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject MediaPlayer2Player::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_MediaPlayer2Player.data,
      qt_meta_data_MediaPlayer2Player,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *MediaPlayer2Player::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaPlayer2Player::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_MediaPlayer2Player.stringdata0))
        return static_cast<void*>(const_cast< MediaPlayer2Player*>(this));
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MediaPlayer2Player::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 15;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void MediaPlayer2Player::Seeked(qlonglong _t1)const
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< MediaPlayer2Player *>(this), &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
