/****************************************************************************
** Meta object code from reading C++ file 'analyzerBase.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/app/analyzer/analyzerBase.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'analyzerBase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Analyzer__Base_t {
    QByteArrayData data[6];
    char stringdata0[96];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Analyzer__Base_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Analyzer__Base_t qt_meta_stringdata_Analyzer__Base = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Analyzer::Base"
QT_MOC_LITERAL(1, 15, 9), // "drawFrame"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 55), // "QMap<Phonon::AudioDataOutput:..."
QT_MOC_LITERAL(4, 82, 8), // "thescope"
QT_MOC_LITERAL(5, 91, 4) // "demo"

    },
    "Analyzer::Base\0drawFrame\0\0"
    "QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >\0"
    "thescope\0demo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Analyzer__Base[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       5,    0,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void Analyzer::Base::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Base *_t = static_cast<Base *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->drawFrame((*reinterpret_cast< const QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >(*)>(_a[1]))); break;
        case 1: _t->demo(); break;
        default: ;
        }
    }
}

const QMetaObject Analyzer::Base::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Analyzer__Base.data,
      qt_meta_data_Analyzer__Base,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Analyzer::Base::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Analyzer::Base::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Analyzer__Base.stringdata0))
        return static_cast<void*>(const_cast< Base*>(this));
    return QWidget::qt_metacast(_clname);
}

int Analyzer::Base::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_Analyzer__Base2D_t {
    QByteArrayData data[3];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Analyzer__Base2D_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Analyzer__Base2D_t qt_meta_stringdata_Analyzer__Base2D = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Analyzer::Base2D"
QT_MOC_LITERAL(1, 17, 4), // "init"
QT_MOC_LITERAL(2, 22, 0) // ""

    },
    "Analyzer::Base2D\0init\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Analyzer__Base2D[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void Analyzer::Base2D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Base2D *_t = static_cast<Base2D *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->init(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject Analyzer::Base2D::staticMetaObject = {
    { &Base::staticMetaObject, qt_meta_stringdata_Analyzer__Base2D.data,
      qt_meta_data_Analyzer__Base2D,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Analyzer::Base2D::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Analyzer::Base2D::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Analyzer__Base2D.stringdata0))
        return static_cast<void*>(const_cast< Base2D*>(this));
    return Base::qt_metacast(_clname);
}

int Analyzer::Base2D::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Base::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
