/****************************************************************************
** Meta object code from reading C++ file 'mediaplayer2.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/mpris2/mediaplayer2.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplayer2.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_MediaPlayer2_t {
    QByteArrayData data[17];
    char stringdata0[215];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MediaPlayer2_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MediaPlayer2_t qt_meta_stringdata_MediaPlayer2 = {
    {
QT_MOC_LITERAL(0, 0, 12), // "MediaPlayer2"
QT_MOC_LITERAL(1, 13, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 29, 22), // "org.mpris.MediaPlayer2"
QT_MOC_LITERAL(3, 52, 5), // "Raise"
QT_MOC_LITERAL(4, 58, 0), // ""
QT_MOC_LITERAL(5, 59, 4), // "Quit"
QT_MOC_LITERAL(6, 64, 20), // "emitFullscreenChange"
QT_MOC_LITERAL(7, 85, 10), // "fullscreen"
QT_MOC_LITERAL(8, 96, 7), // "CanQuit"
QT_MOC_LITERAL(9, 104, 8), // "CanRaise"
QT_MOC_LITERAL(10, 113, 10), // "Fullscreen"
QT_MOC_LITERAL(11, 124, 16), // "CanSetFullscreen"
QT_MOC_LITERAL(12, 141, 12), // "HasTrackList"
QT_MOC_LITERAL(13, 154, 8), // "Identity"
QT_MOC_LITERAL(14, 163, 12), // "DesktopEntry"
QT_MOC_LITERAL(15, 176, 19), // "SupportedUriSchemes"
QT_MOC_LITERAL(16, 196, 18) // "SupportedMimeTypes"

    },
    "MediaPlayer2\0D-Bus Interface\0"
    "org.mpris.MediaPlayer2\0Raise\0\0Quit\0"
    "emitFullscreenChange\0fullscreen\0CanQuit\0"
    "CanRaise\0Fullscreen\0CanSetFullscreen\0"
    "HasTrackList\0Identity\0DesktopEntry\0"
    "SupportedUriSchemes\0SupportedMimeTypes"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MediaPlayer2[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       9,   36, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    0,   31,    4, 0x0a /* Public */,
       5,    0,   32,    4, 0x0a /* Public */,
       6,    1,   33,    4, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,

 // properties: name, type, flags
       8, QMetaType::Bool, 0x00095001,
       9, QMetaType::Bool, 0x00095001,
      10, QMetaType::Bool, 0x00095103,
      11, QMetaType::Bool, 0x00095001,
      12, QMetaType::Bool, 0x00095001,
      13, QMetaType::QString, 0x00095001,
      14, QMetaType::QString, 0x00095001,
      15, QMetaType::QStringList, 0x00095001,
      16, QMetaType::QStringList, 0x00095001,

       0        // eod
};

void MediaPlayer2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MediaPlayer2 *_t = static_cast<MediaPlayer2 *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->Raise(); break;
        case 1: _t->Quit(); break;
        case 2: _t->emitFullscreenChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        MediaPlayer2 *_t = static_cast<MediaPlayer2 *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->CanQuit(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->CanRaise(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->Fullscreen(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->CanSetFullscreen(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->HasTrackList(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->Identity(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->DesktopEntry(); break;
        case 7: *reinterpret_cast< QStringList*>(_v) = _t->SupportedUriSchemes(); break;
        case 8: *reinterpret_cast< QStringList*>(_v) = _t->SupportedMimeTypes(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        MediaPlayer2 *_t = static_cast<MediaPlayer2 *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setFullscreen(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject MediaPlayer2::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_MediaPlayer2.data,
      qt_meta_data_MediaPlayer2,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *MediaPlayer2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaPlayer2::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_MediaPlayer2.stringdata0))
        return static_cast<void*>(const_cast< MediaPlayer2*>(this));
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MediaPlayer2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_END_MOC_NAMESPACE
