/****************************************************************************
** Meta object code from reading C++ file 'mainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/app/mainWindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Dragon__MainWindow_t {
    QByteArrayData data[31];
    char stringdata0[464];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dragon__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dragon__MainWindow_t qt_meta_stringdata_Dragon__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Dragon::MainWindow"
QT_MOC_LITERAL(1, 19, 11), // "fileChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 4), // "open"
QT_MOC_LITERAL(4, 37, 8), // "playDisc"
QT_MOC_LITERAL(5, 46, 14), // "openFileDialog"
QT_MOC_LITERAL(6, 61, 16), // "openStreamDialog"
QT_MOC_LITERAL(7, 78, 4), // "play"
QT_MOC_LITERAL(8, 83, 19), // "toggleVideoSettings"
QT_MOC_LITERAL(9, 103, 18), // "toggleVolumeSlider"
QT_MOC_LITERAL(10, 122, 27), // "restoreDefaultVideoSettings"
QT_MOC_LITERAL(11, 150, 14), // "toggleLoadView"
QT_MOC_LITERAL(12, 165, 13), // "setFullScreen"
QT_MOC_LITERAL(13, 179, 4), // "full"
QT_MOC_LITERAL(14, 184, 13), // "engineMessage"
QT_MOC_LITERAL(15, 198, 4), // "init"
QT_MOC_LITERAL(16, 203, 15), // "aboutToShowMenu"
QT_MOC_LITERAL(17, 219, 19), // "streamSettingChange"
QT_MOC_LITERAL(18, 239, 18), // "subChannelsChanged"
QT_MOC_LITERAL(19, 258, 15), // "QList<QAction*>"
QT_MOC_LITERAL(20, 274, 20), // "audioChannelsChanged"
QT_MOC_LITERAL(21, 295, 12), // "mutedChanged"
QT_MOC_LITERAL(22, 308, 4), // "stop"
QT_MOC_LITERAL(23, 313, 18), // "engineStateChanged"
QT_MOC_LITERAL(24, 332, 13), // "Phonon::State"
QT_MOC_LITERAL(25, 346, 18), // "engineMediaChanged"
QT_MOC_LITERAL(26, 365, 19), // "Phonon::MediaSource"
QT_MOC_LITERAL(27, 385, 21), // "engineSeekableChanged"
QT_MOC_LITERAL(28, 407, 21), // "engineMetaDataChanged"
QT_MOC_LITERAL(29, 429, 21), // "engineHasVideoChanged"
QT_MOC_LITERAL(30, 451, 12) // "toggleUnique"

    },
    "Dragon::MainWindow\0fileChanged\0\0open\0"
    "playDisc\0openFileDialog\0openStreamDialog\0"
    "play\0toggleVideoSettings\0toggleVolumeSlider\0"
    "restoreDefaultVideoSettings\0toggleLoadView\0"
    "setFullScreen\0full\0engineMessage\0init\0"
    "aboutToShowMenu\0streamSettingChange\0"
    "subChannelsChanged\0QList<QAction*>\0"
    "audioChannelsChanged\0mutedChanged\0"
    "stop\0engineStateChanged\0Phonon::State\0"
    "engineMediaChanged\0Phonon::MediaSource\0"
    "engineSeekableChanged\0engineMetaDataChanged\0"
    "engineHasVideoChanged\0toggleUnique"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dragon__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  139,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  142,    2, 0x0a /* Public */,
       4,    0,  145,    2, 0x0a /* Public */,
       5,    0,  146,    2, 0x0a /* Public */,
       6,    0,  147,    2, 0x0a /* Public */,
       7,    0,  148,    2, 0x0a /* Public */,
       8,    1,  149,    2, 0x0a /* Public */,
       9,    1,  152,    2, 0x0a /* Public */,
      10,    0,  155,    2, 0x0a /* Public */,
      11,    0,  156,    2, 0x0a /* Public */,
      12,    1,  157,    2, 0x08 /* Private */,
      14,    1,  160,    2, 0x08 /* Private */,
      15,    0,  163,    2, 0x08 /* Private */,
      16,    0,  164,    2, 0x08 /* Private */,
      17,    0,  165,    2, 0x08 /* Private */,
      18,    1,  166,    2, 0x08 /* Private */,
      20,    1,  169,    2, 0x08 /* Private */,
      21,    1,  172,    2, 0x08 /* Private */,
      22,    0,  175,    2, 0x08 /* Private */,
      23,    1,  176,    2, 0x08 /* Private */,
      25,    1,  179,    2, 0x08 /* Private */,
      27,    1,  182,    2, 0x08 /* Private */,
      28,    0,  185,    2, 0x08 /* Private */,
      29,    1,  186,    2, 0x08 /* Private */,
      30,    1,  189,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Bool, QMetaType::QUrl,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,    2,
    QMetaType::Void, 0x80000000 | 19,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 24,    2,
    QMetaType::Void, 0x80000000 | 26,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void Dragon::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: { bool _r = _t->open((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 2: _t->playDisc(); break;
        case 3: _t->openFileDialog(); break;
        case 4: _t->openStreamDialog(); break;
        case 5: _t->play(); break;
        case 6: _t->toggleVideoSettings((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->toggleVolumeSlider((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->restoreDefaultVideoSettings(); break;
        case 9: _t->toggleLoadView(); break;
        case 10: _t->setFullScreen((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->engineMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->init(); break;
        case 13: _t->aboutToShowMenu(); break;
        case 14: _t->streamSettingChange(); break;
        case 15: _t->subChannelsChanged((*reinterpret_cast< QList<QAction*>(*)>(_a[1]))); break;
        case 16: _t->audioChannelsChanged((*reinterpret_cast< QList<QAction*>(*)>(_a[1]))); break;
        case 17: _t->mutedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->stop(); break;
        case 19: _t->engineStateChanged((*reinterpret_cast< Phonon::State(*)>(_a[1]))); break;
        case 20: _t->engineMediaChanged((*reinterpret_cast< Phonon::MediaSource(*)>(_a[1]))); break;
        case 21: _t->engineSeekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->engineMetaDataChanged(); break;
        case 23: _t->engineHasVideoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->toggleUnique((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MainWindow::*_t)(QString );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MainWindow::fileChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Dragon::MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Dragon__MainWindow.data,
      qt_meta_data_Dragon__MainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Dragon::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dragon::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Dragon__MainWindow.stringdata0))
        return static_cast<void*>(const_cast< MainWindow*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Dragon::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void Dragon::MainWindow::fileChanged(QString _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
