#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'loadView.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOADVIEW_H
#define UI_LOADVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "recentlyPlayedList.h"

QT_BEGIN_NAMESPACE

class Ui_LoadView
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_3;
    QPushButton *m_playFileButton;
    QPushButton *m_playDiskButton;
    QPushButton *m_playStreamButton;
    QSpacerItem *verticalSpacer;
    QWidget *m_vThumb;
    RecentlyPlayedList *m_recentlyPlayed;

    void setupUi(QWidget *LoadView)
    {
        if (LoadView->objectName().isEmpty())
            LoadView->setObjectName(QStringLiteral("LoadView"));
        LoadView->resize(400, 294);
        gridLayout = new QGridLayout(LoadView);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        m_playFileButton = new QPushButton(LoadView);
        m_playFileButton->setObjectName(QStringLiteral("m_playFileButton"));
        QIcon icon;
        QString iconThemeName = QStringLiteral("folder");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        m_playFileButton->setIcon(icon);

        verticalLayout_3->addWidget(m_playFileButton);

        m_playDiskButton = new QPushButton(LoadView);
        m_playDiskButton->setObjectName(QStringLiteral("m_playDiskButton"));
        QIcon icon1;
        iconThemeName = QStringLiteral("media-optical");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        m_playDiskButton->setIcon(icon1);

        verticalLayout_3->addWidget(m_playDiskButton);

        m_playStreamButton = new QPushButton(LoadView);
        m_playStreamButton->setObjectName(QStringLiteral("m_playStreamButton"));
        QIcon icon2(QIcon::fromTheme(QStringLiteral("document-open-remote")));
        m_playStreamButton->setIcon(icon2);

        verticalLayout_3->addWidget(m_playStreamButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        m_vThumb = new QWidget(LoadView);
        m_vThumb->setObjectName(QStringLiteral("m_vThumb"));
        m_vThumb->setMinimumSize(QSize(0, 80));
        m_vThumb->setAutoFillBackground(false);

        verticalLayout_3->addWidget(m_vThumb);


        gridLayout->addLayout(verticalLayout_3, 0, 0, 1, 1);

        m_recentlyPlayed = new RecentlyPlayedList(LoadView);
        m_recentlyPlayed->setObjectName(QStringLiteral("m_recentlyPlayed"));

        gridLayout->addWidget(m_recentlyPlayed, 0, 1, 1, 1);


        retranslateUi(LoadView);

        QMetaObject::connectSlotsByName(LoadView);
    } // setupUi

    void retranslateUi(QWidget *LoadView)
    {
        m_playFileButton->setText(tr2i18n("Play File", 0));
        m_playDiskButton->setText(tr2i18n("Play Disc", 0));
        m_playStreamButton->setText(tr2i18n("Play Stream", 0));
        Q_UNUSED(LoadView);
    } // retranslateUi

};

namespace Ui {
    class LoadView: public Ui_LoadView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOADVIEW_H

