#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'videoSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIDEOSETTINGSWIDGET_H
#define UI_VIDEOSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace Dragon {

class Ui_VideoSettingsWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *brightnessLabel;
    QSlider *brightnessSlider;
    QLabel *contrastLabel;
    QSlider *contrastSlider;
    QLabel *hueLabel;
    QSlider *hueSlider;
    QLabel *saturationLabel;
    QSlider *saturationSlider;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *defaultsButton;
    QPushButton *closeButton;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *Dragon__VideoSettingsWidget)
    {
        if (Dragon__VideoSettingsWidget->objectName().isEmpty())
            Dragon__VideoSettingsWidget->setObjectName(QStringLiteral("Dragon__VideoSettingsWidget"));
        Dragon__VideoSettingsWidget->resize(203, 148);
        vboxLayout = new QVBoxLayout(Dragon__VideoSettingsWidget);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        brightnessLabel = new QLabel(Dragon__VideoSettingsWidget);
        brightnessLabel->setObjectName(QStringLiteral("brightnessLabel"));

        gridLayout->addWidget(brightnessLabel, 0, 0, 1, 1);

        brightnessSlider = new QSlider(Dragon__VideoSettingsWidget);
        brightnessSlider->setObjectName(QStringLiteral("brightnessSlider"));
        brightnessSlider->setMinimum(-100);
        brightnessSlider->setMaximum(100);
        brightnessSlider->setOrientation(Qt::Horizontal);
        brightnessSlider->setTickPosition(QSlider::NoTicks);

        gridLayout->addWidget(brightnessSlider, 0, 1, 1, 1);

        contrastLabel = new QLabel(Dragon__VideoSettingsWidget);
        contrastLabel->setObjectName(QStringLiteral("contrastLabel"));

        gridLayout->addWidget(contrastLabel, 1, 0, 1, 1);

        contrastSlider = new QSlider(Dragon__VideoSettingsWidget);
        contrastSlider->setObjectName(QStringLiteral("contrastSlider"));
        contrastSlider->setMinimum(-100);
        contrastSlider->setMaximum(100);
        contrastSlider->setOrientation(Qt::Horizontal);
        contrastSlider->setTickPosition(QSlider::NoTicks);

        gridLayout->addWidget(contrastSlider, 1, 1, 1, 1);

        hueLabel = new QLabel(Dragon__VideoSettingsWidget);
        hueLabel->setObjectName(QStringLiteral("hueLabel"));

        gridLayout->addWidget(hueLabel, 2, 0, 1, 1);

        hueSlider = new QSlider(Dragon__VideoSettingsWidget);
        hueSlider->setObjectName(QStringLiteral("hueSlider"));
        hueSlider->setMinimum(-100);
        hueSlider->setMaximum(100);
        hueSlider->setOrientation(Qt::Horizontal);
        hueSlider->setTickPosition(QSlider::NoTicks);

        gridLayout->addWidget(hueSlider, 2, 1, 1, 1);

        saturationLabel = new QLabel(Dragon__VideoSettingsWidget);
        saturationLabel->setObjectName(QStringLiteral("saturationLabel"));

        gridLayout->addWidget(saturationLabel, 3, 0, 1, 1);

        saturationSlider = new QSlider(Dragon__VideoSettingsWidget);
        saturationSlider->setObjectName(QStringLiteral("saturationSlider"));
        saturationSlider->setMinimum(-100);
        saturationSlider->setMaximum(100);
        saturationSlider->setOrientation(Qt::Horizontal);
        saturationSlider->setTickPosition(QSlider::NoTicks);

        gridLayout->addWidget(saturationSlider, 3, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        defaultsButton = new QPushButton(Dragon__VideoSettingsWidget);
        defaultsButton->setObjectName(QStringLiteral("defaultsButton"));

        hboxLayout->addWidget(defaultsButton);

        closeButton = new QPushButton(Dragon__VideoSettingsWidget);
        closeButton->setObjectName(QStringLiteral("closeButton"));

        hboxLayout->addWidget(closeButton);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(Dragon__VideoSettingsWidget);

        QMetaObject::connectSlotsByName(Dragon__VideoSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *Dragon__VideoSettingsWidget)
    {
        brightnessLabel->setText(tr2i18n("Brightness:", 0));
        contrastLabel->setText(tr2i18n("Contrast:", 0));
        hueLabel->setText(tr2i18n("Hue:", 0));
        saturationLabel->setText(tr2i18n("Saturation:", 0));
        defaultsButton->setText(tr2i18n("Restore Defaults", 0));
        closeButton->setText(tr2i18n("Close", 0));
        Q_UNUSED(Dragon__VideoSettingsWidget);
    } // retranslateUi

};

} // namespace Dragon

namespace Dragon {
namespace Ui {
    class VideoSettingsWidget: public Ui_VideoSettingsWidget {};
} // namespace Ui
} // namespace Dragon

#endif // VIDEOSETTINGSWIDGET_H

