/****************************************************************************
** Meta object code from reading C++ file 'videoWindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/app/videoWindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videoWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Dragon__VideoWindow_t {
    QByteArrayData data[41];
    char stringdata0[537];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dragon__VideoWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dragon__VideoWindow_t qt_meta_stringdata_Dragon__VideoWindow = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Dragon::VideoWindow"
QT_MOC_LITERAL(1, 20, 12), // "stateUpdated"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 13), // "Phonon::State"
QT_MOC_LITERAL(4, 48, 18), // "subChannelsChanged"
QT_MOC_LITERAL(5, 67, 15), // "QList<QAction*>"
QT_MOC_LITERAL(6, 83, 20), // "audioChannelsChanged"
QT_MOC_LITERAL(7, 104, 4), // "tick"
QT_MOC_LITERAL(8, 109, 20), // "currentSourceChanged"
QT_MOC_LITERAL(9, 130, 19), // "Phonon::MediaSource"
QT_MOC_LITERAL(10, 150, 16), // "totalTimeChanged"
QT_MOC_LITERAL(11, 167, 12), // "mutedChanged"
QT_MOC_LITERAL(12, 180, 15), // "seekableChanged"
QT_MOC_LITERAL(13, 196, 15), // "metaDataChanged"
QT_MOC_LITERAL(14, 212, 15), // "hasVideoChanged"
QT_MOC_LITERAL(15, 228, 13), // "volumeChanged"
QT_MOC_LITERAL(16, 242, 8), // "finished"
QT_MOC_LITERAL(17, 251, 5), // "pause"
QT_MOC_LITERAL(18, 257, 9), // "playPause"
QT_MOC_LITERAL(19, 267, 4), // "seek"
QT_MOC_LITERAL(20, 272, 4), // "stop"
QT_MOC_LITERAL(21, 277, 12), // "stateChanged"
QT_MOC_LITERAL(22, 290, 14), // "settingChanged"
QT_MOC_LITERAL(23, 305, 4), // "mute"
QT_MOC_LITERAL(24, 310, 13), // "toggleDVDMenu"
QT_MOC_LITERAL(25, 324, 7), // "showOSD"
QT_MOC_LITERAL(26, 332, 15), // "slotSetSubtitle"
QT_MOC_LITERAL(27, 348, 12), // "slotSetAudio"
QT_MOC_LITERAL(28, 361, 9), // "resetZoom"
QT_MOC_LITERAL(29, 371, 11), // "prevChapter"
QT_MOC_LITERAL(30, 383, 11), // "nextChapter"
QT_MOC_LITERAL(31, 395, 14), // "tenPercentBack"
QT_MOC_LITERAL(32, 410, 17), // "tenPercentForward"
QT_MOC_LITERAL(33, 428, 14), // "tenSecondsBack"
QT_MOC_LITERAL(34, 443, 17), // "tenSecondsForward"
QT_MOC_LITERAL(35, 461, 14), // "increaseVolume"
QT_MOC_LITERAL(36, 476, 14), // "decreaseVolume"
QT_MOC_LITERAL(37, 491, 9), // "canGoPrev"
QT_MOC_LITERAL(38, 501, 9), // "canGoNext"
QT_MOC_LITERAL(39, 511, 14), // "updateChannels"
QT_MOC_LITERAL(40, 526, 10) // "hideCursor"

    },
    "Dragon::VideoWindow\0stateUpdated\0\0"
    "Phonon::State\0subChannelsChanged\0"
    "QList<QAction*>\0audioChannelsChanged\0"
    "tick\0currentSourceChanged\0Phonon::MediaSource\0"
    "totalTimeChanged\0mutedChanged\0"
    "seekableChanged\0metaDataChanged\0"
    "hasVideoChanged\0volumeChanged\0finished\0"
    "pause\0playPause\0seek\0stop\0stateChanged\0"
    "settingChanged\0mute\0toggleDVDMenu\0"
    "showOSD\0slotSetSubtitle\0slotSetAudio\0"
    "resetZoom\0prevChapter\0nextChapter\0"
    "tenPercentBack\0tenPercentForward\0"
    "tenSecondsBack\0tenSecondsForward\0"
    "increaseVolume\0decreaseVolume\0canGoPrev\0"
    "canGoNext\0updateChannels\0hideCursor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dragon__VideoWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      36,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  194,    2, 0x06 /* Public */,
       4,    1,  199,    2, 0x06 /* Public */,
       6,    1,  202,    2, 0x06 /* Public */,
       7,    1,  205,    2, 0x06 /* Public */,
       8,    1,  208,    2, 0x06 /* Public */,
      10,    1,  211,    2, 0x06 /* Public */,
      11,    1,  214,    2, 0x06 /* Public */,
      12,    1,  217,    2, 0x06 /* Public */,
      13,    0,  220,    2, 0x06 /* Public */,
      14,    1,  221,    2, 0x06 /* Public */,
      15,    1,  224,    2, 0x06 /* Public */,
      16,    0,  227,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    0,  228,    2, 0x0a /* Public */,
      18,    0,  229,    2, 0x0a /* Public */,
      19,    1,  230,    2, 0x0a /* Public */,
      20,    0,  233,    2, 0x0a /* Public */,
      21,    2,  234,    2, 0x0a /* Public */,
      22,    1,  239,    2, 0x0a /* Public */,
      23,    1,  242,    2, 0x0a /* Public */,
      24,    0,  245,    2, 0x0a /* Public */,
      25,    1,  246,    2, 0x0a /* Public */,
      26,    0,  249,    2, 0x0a /* Public */,
      27,    0,  250,    2, 0x0a /* Public */,
      28,    0,  251,    2, 0x0a /* Public */,
      29,    0,  252,    2, 0x0a /* Public */,
      30,    0,  253,    2, 0x0a /* Public */,
      31,    0,  254,    2, 0x0a /* Public */,
      32,    0,  255,    2, 0x0a /* Public */,
      33,    0,  256,    2, 0x0a /* Public */,
      34,    0,  257,    2, 0x0a /* Public */,
      35,    0,  258,    2, 0x0a /* Public */,
      36,    0,  259,    2, 0x0a /* Public */,
      37,    0,  260,    2, 0x0a /* Public */,
      38,    0,  261,    2, 0x0a /* Public */,
      39,    0,  262,    2, 0x08 /* Private */,
      40,    0,  263,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    2,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Dragon::VideoWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VideoWindow *_t = static_cast<VideoWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stateUpdated((*reinterpret_cast< const Phonon::State(*)>(_a[1])),(*reinterpret_cast< const Phonon::State(*)>(_a[2]))); break;
        case 1: _t->subChannelsChanged((*reinterpret_cast< QList<QAction*>(*)>(_a[1]))); break;
        case 2: _t->audioChannelsChanged((*reinterpret_cast< QList<QAction*>(*)>(_a[1]))); break;
        case 3: _t->tick((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 4: _t->currentSourceChanged((*reinterpret_cast< const Phonon::MediaSource(*)>(_a[1]))); break;
        case 5: _t->totalTimeChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 6: _t->mutedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->seekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->metaDataChanged(); break;
        case 9: _t->hasVideoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->volumeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 11: _t->finished(); break;
        case 12: _t->pause(); break;
        case 13: _t->playPause(); break;
        case 14: _t->seek((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 15: _t->stop(); break;
        case 16: _t->stateChanged((*reinterpret_cast< Phonon::State(*)>(_a[1])),(*reinterpret_cast< Phonon::State(*)>(_a[2]))); break;
        case 17: _t->settingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->mute((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->toggleDVDMenu(); break;
        case 20: _t->showOSD((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->slotSetSubtitle(); break;
        case 22: _t->slotSetAudio(); break;
        case 23: _t->resetZoom(); break;
        case 24: _t->prevChapter(); break;
        case 25: _t->nextChapter(); break;
        case 26: _t->tenPercentBack(); break;
        case 27: _t->tenPercentForward(); break;
        case 28: _t->tenSecondsBack(); break;
        case 29: _t->tenSecondsForward(); break;
        case 30: _t->increaseVolume(); break;
        case 31: _t->decreaseVolume(); break;
        case 32: { bool _r = _t->canGoPrev();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 33: { bool _r = _t->canGoNext();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 34: _t->updateChannels(); break;
        case 35: _t->hideCursor(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (VideoWindow::*_t)(const Phonon::State , const Phonon::State );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::stateUpdated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(QList<QAction*> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::subChannelsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(QList<QAction*> );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::audioChannelsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::tick)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(const Phonon::MediaSource );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::currentSourceChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::totalTimeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::mutedChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::seekableChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::metaDataChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::hasVideoChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)(qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::volumeChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (VideoWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VideoWindow::finished)) {
                *result = 11;
                return;
            }
        }
    }
}

const QMetaObject Dragon::VideoWindow::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Dragon__VideoWindow.data,
      qt_meta_data_Dragon__VideoWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Dragon::VideoWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dragon::VideoWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Dragon__VideoWindow.stringdata0))
        return static_cast<void*>(const_cast< VideoWindow*>(this));
    return QWidget::qt_metacast(_clname);
}

int Dragon::VideoWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void Dragon::VideoWindow::stateUpdated(const Phonon::State _t1, const Phonon::State _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dragon::VideoWindow::subChannelsChanged(QList<QAction*> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dragon::VideoWindow::audioChannelsChanged(QList<QAction*> _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dragon::VideoWindow::tick(qint64 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dragon::VideoWindow::currentSourceChanged(const Phonon::MediaSource _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dragon::VideoWindow::totalTimeChanged(qint64 _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dragon::VideoWindow::mutedChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dragon::VideoWindow::seekableChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Dragon::VideoWindow::metaDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, Q_NULLPTR);
}

// SIGNAL 9
void Dragon::VideoWindow::hasVideoChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Dragon::VideoWindow::volumeChanged(qreal _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Dragon::VideoWindow::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 11, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
