/****************************************************************************
** Meta object code from reading C++ file 'loadView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/dragon-17.04.3/src/app/loadView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'loadView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Dragon__LoadView_t {
    QByteArrayData data[7];
    char stringdata0[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dragon__LoadView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dragon__LoadView_t qt_meta_stringdata_Dragon__LoadView = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Dragon::LoadView"
QT_MOC_LITERAL(1, 17, 7), // "loadUrl"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 15), // "openFilePressed"
QT_MOC_LITERAL(4, 42, 14), // "openDVDPressed"
QT_MOC_LITERAL(5, 57, 17), // "openStreamPressed"
QT_MOC_LITERAL(6, 75, 18) // "reloadRecentlyList"

    },
    "Dragon::LoadView\0loadUrl\0\0openFilePressed\0"
    "openDVDPressed\0openStreamPressed\0"
    "reloadRecentlyList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dragon__LoadView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       3,    0,   42,    2, 0x06 /* Public */,
       4,    0,   43,    2, 0x06 /* Public */,
       5,    0,   44,    2, 0x06 /* Public */,
       6,    0,   45,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Dragon::LoadView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LoadView *_t = static_cast<LoadView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loadUrl((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 1: _t->openFilePressed(); break;
        case 2: _t->openDVDPressed(); break;
        case 3: _t->openStreamPressed(); break;
        case 4: _t->reloadRecentlyList(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (LoadView::*_t)(QUrl );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&LoadView::loadUrl)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (LoadView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&LoadView::openFilePressed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (LoadView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&LoadView::openDVDPressed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (LoadView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&LoadView::openStreamPressed)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (LoadView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&LoadView::reloadRecentlyList)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject Dragon::LoadView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Dragon__LoadView.data,
      qt_meta_data_Dragon__LoadView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Dragon::LoadView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dragon::LoadView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Dragon__LoadView.stringdata0))
        return static_cast<void*>(const_cast< LoadView*>(this));
    return QWidget::qt_metacast(_clname);
}

int Dragon::LoadView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Dragon::LoadView::loadUrl(QUrl _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dragon::LoadView::openFilePressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void Dragon::LoadView::openDVDPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void Dragon::LoadView::openStreamPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void Dragon::LoadView::reloadRecentlyList()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
