#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'audioView2.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDIOVIEW2_H
#define UI_AUDIOVIEW2_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "analyzer/blockAnalyzer.h"

namespace Dragon {

class Ui_AudioView2
{
public:
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QFrame *m_analyzerFrame;
    QVBoxLayout *verticalLayout_3;
    QLabel *m_track;
    QLabel *m_artist;
    QLabel *m_album;
    BlockAnalyzer *m_analyzer;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Dragon__AudioView2)
    {
        if (Dragon__AudioView2->objectName().isEmpty())
            Dragon__AudioView2->setObjectName(QStringLiteral("Dragon__AudioView2"));
        Dragon__AudioView2->resize(794, 622);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Dragon__AudioView2->sizePolicy().hasHeightForWidth());
        Dragon__AudioView2->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(Dragon__AudioView2);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Minimum, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_analyzerFrame = new QFrame(Dragon__AudioView2);
        m_analyzerFrame->setObjectName(QStringLiteral("m_analyzerFrame"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_analyzerFrame->sizePolicy().hasHeightForWidth());
        m_analyzerFrame->setSizePolicy(sizePolicy1);
        m_analyzerFrame->setFrameShape(QFrame::NoFrame);
        m_analyzerFrame->setFrameShadow(QFrame::Sunken);
        verticalLayout_3 = new QVBoxLayout(m_analyzerFrame);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        m_track = new QLabel(m_analyzerFrame);
        m_track->setObjectName(QStringLiteral("m_track"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        m_track->setFont(font);
        m_track->setText(QStringLiteral(""));

        verticalLayout_3->addWidget(m_track);

        m_artist = new QLabel(m_analyzerFrame);
        m_artist->setObjectName(QStringLiteral("m_artist"));
        m_artist->setText(QStringLiteral(""));

        verticalLayout_3->addWidget(m_artist);

        m_album = new QLabel(m_analyzerFrame);
        m_album->setObjectName(QStringLiteral("m_album"));
        m_album->setText(QStringLiteral(""));

        verticalLayout_3->addWidget(m_album);

        m_analyzer = new BlockAnalyzer(m_analyzerFrame);
        m_analyzer->setObjectName(QStringLiteral("m_analyzer"));

        verticalLayout_3->addWidget(m_analyzer);


        horizontalLayout->addWidget(m_analyzerFrame);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Minimum, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(Dragon__AudioView2);

        QMetaObject::connectSlotsByName(Dragon__AudioView2);
    } // setupUi

    void retranslateUi(QWidget *Dragon__AudioView2)
    {
        Q_UNUSED(Dragon__AudioView2);
    } // retranslateUi

};

} // namespace Dragon

namespace Dragon {
namespace Ui {
    class AudioView2: public Ui_AudioView2 {};
} // namespace Ui
} // namespace Dragon

#endif // AUDIOVIEW2_H

